@@ -1,11 +1,12 @@
-from .babel.views import LocaleView
+
 from .security.manager import SecurityManager
     
 from .views import IndexView
 from filters import TemplateFilters
 from flask import Blueprint
-from flask.ext.babel import gettext as _gettext, lazy_gettext
+from flask.ext.babelpkg import gettext as _gettext, lazy_gettext
 from flask.ext.appbuilder.babel.manager import BabelManager
+from flask.ext.appbuilder import translations
 from menu import Menu
 
 
@@ -25,10 +26,11 @@ class BaseApp():
     lst_baseview = []
     app = None
     db = None
-    # Security Manager
-    sm = None
-    babelmanager = None
     
+    sm = None
+    """ Security Manager """
+    bm = None
+    """ Babel Manager """
     app_name = ""
     app_theme = ''
     app_icon = None
@@ -52,6 +54,7 @@ class BaseApp():
                     static_url_path='/appbuilder'):
         """
             BaseApp constructor
+            
             :param app:
                 The flask app object
             :param db:
@@ -69,7 +72,7 @@ class BaseApp():
         self.db = db
                     
         self.sm = SecurityManager(app, db.session)
-        self.babelmanager = BabelManager(app)
+        self.bm = BabelManager(app, pkg_translations=translations)
         
         if menu:
             self.menu = menu
@@ -120,7 +123,7 @@ class BaseApp():
     def _add_admin_views(self):
         self.indexview = self.indexview()
         self.add_view_no_menu(self.indexview)
-        self.add_view_no_menu(LocaleView())
+        self.bm.register_views(self)
         self.sm.register_views(self)
 
     def _init_view_session(self, baseview_class):
