@@ -16,8 +16,6 @@ from views import AuthDBView, AuthOIDView, ResetMyPasswordView, \
     PermissionViewGeneralView, ViewMenuGeneralView, PermissionGeneralView
 
 
-
-
 AUTH_OID = 0
 AUTH_DB = 1
 AUTH_LDAP = 2
@@ -62,23 +60,23 @@ class SecurityManager(object):
         else:
             user_view = baseapp._init_view_session(UserOIDGeneralView)
             self.auth_view = AuthOIDView()            
-            self.oid.after_login_func = auth_view.after_login
+            self.oid.after_login_func = self.auth_view.after_login
         
         baseapp.add_view_no_menu(self.auth_view)
         
         baseapp.add_view(user_view, "List Users"
-                                        ,"/users/list","user",
+                                        ,"/users/list","fa-user",
                                         "Security")
                  
         role_view = baseapp._init_view_session(RoleGeneralView)                       
-        baseapp.add_view(role_view, "List Roles","/roles/list","tags","Security")
+        baseapp.add_view(role_view, "List Roles","/roles/list","fa-group","Security")
         role_view.related_views = [user_view]
         baseapp.menu.add_separator("Security")
-        baseapp.add_view(baseapp._init_view_session(PermissionViewGeneralView), "Base Permissions","/permissions/list","lock","Security")
-        baseapp.add_view(baseapp._init_view_session(ViewMenuGeneralView), "Views/Menus","/viewmenus/list","list-alt","Security")
-        baseapp.add_view(baseapp._init_view_session(PermissionGeneralView), "Permission on Views/Menus","/permissionviews/list","lock","Security")
+        baseapp.add_view(baseapp._init_view_session(PermissionViewGeneralView), "Base Permissions","/permissions/list","fa-lock","Security")
+        baseapp.add_view(baseapp._init_view_session(ViewMenuGeneralView), "Views/Menus","/viewmenus/list","fa-list-alt","Security")
+        baseapp.add_view(baseapp._init_view_session(PermissionGeneralView), "Permission on Views/Menus","/permissionviews/list","fa-link","Security")
+
 
-        
     def load_user(self, pk):
         return self.get_user_by_id(int(pk))
 
@@ -141,7 +139,7 @@ class SecurityManager(object):
             print "Migrating Users"
             self.migrate_obj(old_user, User)
             
-                        
+    
     def init_db(self):
         engine = self.session.get_bind(mapper=None, clause=None)        
         
@@ -279,6 +277,19 @@ class SecurityManager(object):
             return False
         else: return False
     
+    def has_access(self, permission_name, view_name):
+        if current_user.is_authenticated():
+            if self.has_permission_on_view(g.user, permission_name, view_name):
+               return True
+            else:
+               return False
+        else:
+            if self.is_item_public(permission_name, view_name):
+                return True
+            else:
+                return False
+        return False
+    
     def _add_permission(self, name):
         """
             Adds a permission to the backend
