@@ -1,20 +1,22 @@
 from ..forms import BS3PasswordFieldWidget
 from flask import render_template, flash, redirect, session, url_for, request, g, \
     current_app
-from flask.ext.appbuilder.models.datamodel import SQLAModel
-from flask.ext.appbuilder.views import BaseView, GeneralView, SimpleFormView, \
-    AdditionalLinkItem, expose
-from flask.ext.babel import gettext, lazy_gettext
-from flask.ext.login import login_user, logout_user, current_user, \
-    login_required
-from flask.ext.openid import SessionWrapper, OpenIDResponse
-from flask.ext.wtf import Required, Length, validators, EqualTo, PasswordField
-from forms import LoginForm_db, LoginForm_oid, ResetPasswordForm
-from models import User, Permission, PermissionView, Role, ViewMenu
 from openid.consumer import discover
 from openid.consumer.consumer import Consumer, SUCCESS, CANCEL
 from openid.extensions import ax
 from openid.extensions.sreg import SRegRequest, SRegResponse
+from flask.ext.openid import SessionWrapper, OpenIDResponse
+from flask.ext.wtf import Required, Length, validators, EqualTo, PasswordField
+from flask.ext.babelpkg import gettext, lazy_gettext
+from flask.ext.login import login_user, logout_user, current_user, \
+    login_required
+
+from flask.ext.appbuilder.models.datamodel import SQLAModel
+from flask.ext.appbuilder.views import BaseView, GeneralView, SimpleFormView, expose
+from ..actions import action
+from forms import LoginForm_db, LoginForm_oid, ResetPasswordForm
+from models import User, Permission, PermissionView, Role, ViewMenu
+from decorators import has_access
 
 
 class PermissionGeneralView(GeneralView):
@@ -71,8 +73,7 @@ class ResetMyPasswordView(SimpleFormView):
     message = lazy_gettext('Password Changed')
 
     def form_post(self, form):
-        pk = request.args.get('pk')
-        self.baseapp.sm.reset_password(pk, form.password.data)
+        self.baseapp.sm.reset_password(g.user.id, form.password.data)
         flash(unicode(self.message),'info')
 
 
@@ -124,19 +125,19 @@ class UserGeneralView(GeneralView):
     list_columns = ['full_name', 'username', 'email','active', 'role']
     show_columns = ['first_name','last_name','username', 'active', 'email','role']
     order_columns = ['username', 'email']
-    search_columns = ['first_name','last_name', 'username', 'email','active','role']
+    search_columns = ['first_name','last_name', 'username', 'email','role']
 
     add_columns = ['first_name','last_name','username', 'active', 'email','role']
     edit_columns = ['first_name','last_name','username', 'active', 'email','role']
 
     user_info_title = lazy_gettext("Your user information")
-    lnk_reset_password = lazy_gettext("Reset Password")
-
+    
     show_additional_links = []
 
 
 class UserOIDGeneralView(UserGeneralView):
     @expose('/userinfo/')
+    @has_access
     def userinfo(self):
         widgets = self._get_show_widget(g.user.id)
 
@@ -145,7 +146,6 @@ class UserOIDGeneralView(UserGeneralView):
                            widgets = widgets,
                            baseapp = self.baseapp,
                            )
-    
 
 class UserDBGeneralView(UserGeneralView):
     
@@ -159,20 +159,40 @@ class UserDBGeneralView(UserGeneralView):
     
     add_columns = ['first_name','last_name','username', 'active', 'email','role','password','conf_password']
     
-    def __init__(self, **kwargs):
-        self.show_additional_links = [(AdditionalLinkItem('resetpassword', self.lnk_reset_password,"/resetpassword/form","lock"))]
-        super(UserDBGeneralView, self).__init__(**kwargs)
+    @expose('/show/<int:pk>', methods=['GET'])
+    @has_access
+    def show(self, pk):
+        actions = {}
+        actions['resetpasswords'] = self.actions.get('resetpasswords')
+        widgets = self._get_show_widget(pk, actions = actions)
+        return render_template(self.show_template,
+                           pk = pk,
+                           title = self.show_title,
+                           widgets = widgets,
+                           baseapp = self.baseapp,
+                           related_views = self.related_views)
+
 
     @expose('/userinfo/')
+    @has_access
     def userinfo(self):
-        show_additional_links = [AdditionalLinkItem('resetmypassword', self.lnk_reset_password,"/resetmypassword/form","lock")]
-        widgets = self._get_show_widget(g.user.id, show_additional_links = show_additional_links)
+        actions = {}
+        actions['resetmypassword'] = self.actions.get('resetmypassword')
+        widgets = self._get_show_widget(g.user.id, actions = actions)
         return render_template(self.show_template,
                            title = self.user_info_title,
                            widgets = widgets,
                            baseapp = self.baseapp,
                            )
 
+    @action('resetmypassword', lazy_gettext("Reset my password"), "", "fa-lock")
+    def resetmypassword(self, item):
+        return redirect(url_for('ResetMyPasswordView.this_form_get'))
+        
+    @action('resetpasswords', lazy_gettext("Reset Password"), "", "fa-lock")
+    def resetpasswords(self, item):
+        return redirect(url_for('ResetPasswordView.this_form_get', pk=item.id))
+    
 
 class RoleGeneralView(GeneralView):
     route_base = '/roles'
