@@ -1,12 +1,13 @@
 import re
 from flask import Blueprint, render_template, flash, redirect, url_for, request, send_file
 from flask.ext.login import login_required
-from flask.ext.babel import gettext, ngettext, lazy_gettext
+from flask.ext.babelpkg import gettext, ngettext, lazy_gettext
 from forms import GeneralModelConverter
 from .filemanager import uuid_originalname
+from urltools import *
 from .security.decorators import has_access
 from .widgets import FormWidget, ShowWidget, ListWidget, SearchWidget, ListCarousel
-from .actions import ActionItem
+from .actions import ActionItem, action
 from .models.filters import Filters, FilterRelationOneToManyEqual
 
 def expose(url='/', methods=('GET',)):
@@ -44,10 +45,7 @@ class BaseView(object):
     
     template_folder = 'templates'
     static_folder='static'
-    
-    base_permissions = None
-    actions = None
-
+    base_permissions = None    
     default_view = 'list'
 
     def __init__(self):
@@ -61,12 +59,7 @@ class BaseView(object):
                 for attr_name in dir(self)
                 if hasattr(getattr(self, attr_name),'_urls')
                 ]
-            self.actions = self.actions or []
-            for attr_name in dir(self):
-                if hasattr(getattr(self, attr_name),'_action'):
-                    action = ActionItem(*attr_name._action, func = getattr(self, attr_name))
-                    self.base_permissions.append(action.name)
-                    self.actions.append(action)
+
 
     def create_blueprint(self, baseapp, 
                         endpoint = None, 
@@ -116,7 +109,11 @@ class BaseView(object):
                                         attr_name,
                                         attr,
                                         methods=methods)
-        
+    
+    
+    def render_template(self, template, **kwargs):
+        kwargs['_'] = babel.gettext
+        return render_template(template, **kwargs)
 
     def _prettify_name(self, name):
         """
@@ -262,9 +259,22 @@ class BaseModelView(BaseView):
     """
 
     datamodel = None
-    """ Your sqla model you must initialize it like datamodel = SQLAModel(Permission, session) """
+    """ 
+        Your sqla model you must initialize it like::
+        
+            class MyView(GeneralView):
+                datamodel = SQLAModel(MyTable, db.session)
+    """
     search_columns = None
-    """ List with allowed search columns, if not provided all possible search columns will be used """
+    """ 
+        List with allowed search columns, if not provided all possible search columns will be used 
+        If you want to limit the search (*filter*) columns possibilities, define it with a list of column names from your model::
+        
+            class MyView(GeneralView):
+                datamodel = SQLAModel(MyTable, db.session)
+                search_columns = ['name','address']
+             
+    """
     label_columns = None
     """ 
         Dictionary of labels for your columns, override this if you want diferent pretify labels 
@@ -273,7 +283,7 @@ class BaseModelView(BaseView):
         
             class MyView(GeneralView):
                 datamodel = SQLAModel(MyTable, db.session)
-                label_columns = {'name':'My Name Label Overrride'}
+                label_columns = {'name':'My Name Label Override'}
         
     """    
     search_form = None
@@ -323,67 +333,6 @@ class BaseModelView(BaseView):
         if not self.search_form:
             self.search_form = conv.create_form(self.label_columns,
                     {}, {}, [], self.search_columns)
-        
-
-    def _get_group_by_args(self):
-        """
-            Get page arguments for group by
-        """
-        group_by = request.args.get('group_by')
-        if not group_by: group_by = ''
-        return group_by
-
-    def _get_page_args(self):
-        """
-            Get page arguments, returns a dictionary
-            { <VIEW_NAME>: PAGE_NUMBER }
-        
-            Arguments are passed: page_<VIEW_NAME>=<PAGE_NUMBER>
-        
-        """
-        pages = {}
-        for arg in request.args:
-            re_match = re.findall('page_(.*)', arg)
-            if re_match:
-                pages[re_match[0]] = int(request.args.get(arg))
-        return pages
-
-    def _get_page_size_args(self):
-        """
-            Get page size arguments, returns an int
-            { <VIEW_NAME>: PAGE_NUMBER }
-        
-            Arguments are passed: psize_<VIEW_NAME>=<PAGE_SIZE>
-        
-        """
-        page_sizes = {}
-        for arg in request.args:
-            re_match = re.findall('psize_(.*)', arg)
-            if re_match:
-                page_sizes[re_match[0]] = int(request.args.get(arg))
-        return page_sizes
-        
-    def _get_order_args(self):
-        """
-            Get order arguments, return a dictionary
-            { <VIEW_NAME>: (ORDER_COL, ORDER_DIRECTION) }
-        
-            Arguments are passed like: _oc_<VIEW_NAME>=<COL_NAME>&_od_<VIEW_NAME>='asc'|'desc'
-        
-        """
-        orders = {}
-        for arg in request.args:
-            re_match = re.findall('_oc_(.*)', arg)
-            if re_match:
-                orders[re_match[0]] = (request.args.get(arg),request.args.get('_od_' + re_match[0]))
-        return orders
-
-    def _get_filter_args(self):
-        self._filters.clear_filters()
-        for arg in request.args:
-            re_match = re.findall('_flt_(\d)_(.*)', arg)
-            if re_match:
-                self._filters.add_filter_index(re_match[0][1], int(re_match[0][0]), request.args.get(arg))
 
 
     def _get_search_widget(self, form = None, exclude_cols = [], widgets = {}):
@@ -399,24 +348,23 @@ class BaseModelView(BaseView):
 
 class BaseCRUDView(BaseModelView):
     """
-        The base class of GeneralView, all properties are inherited
+        The base class for GeneralView, all properties are inherited
         Customize GeneralView overriding this properties
     """
     
-
     related_views = None
     """ 
         List with instantiated GeneralView classes
         That will be displayed related with this one using relationship sqlalchemy property
     """
     list_title = ""
-    """ List Title """
+    """ List Title, if not configured the default is 'List ' with pretty model name """
     show_title = ""
-    """ Show Title """
+    """ Show Title , if not configured the default is 'Show ' with pretty model name """
     add_title = ""
-    """ Add Title """
+    """ Add Title , if not configured the default is 'Add ' with pretty model name """
     edit_title = ""
-    """ Edit Title """
+    """ Edit Title , if not configured the default is 'Edit ' with pretty model name """
 
     list_columns = None
     """ Include Columns for lists view """
@@ -430,7 +378,9 @@ class BaseCRUDView(BaseModelView):
     """ Allowed order columns """
     
     page_size = 10
-    """ Page size """
+    """ 
+        Use this property to change default page size 
+    """
     
     show_fieldsets = None
     """ 
@@ -457,7 +407,14 @@ class BaseCRUDView(BaseModelView):
     """
     
     description_columns = None
-    """ Dictionary with column descriptions that will be shown on the forms """
+    """ 
+        Dictionary with column descriptions that will be shown on the forms::
+        
+            class MyView(GeneralView):
+                datamodel = SQLAModel(MyTable, db.session)
+
+                description_columns = {'name','your models name column','address','the address column'}
+    """
     validators_columns = None
     """ Dictionary to add your own validators for forms """
     add_form_extra_fields = None
@@ -492,15 +449,23 @@ class BaseCRUDView(BaseModelView):
     search_widget = SearchWidget
     """ Search widget you can override with your own """
         
-    show_additional_links = []
+    actions = None
 
     def __init__(self, **kwargs):
         super(BaseCRUDView, self).__init__(**kwargs)
         self._init_properties()
         self._init_forms()
         self._init_titles()
-        
-    
+
+        self.actions = {}
+        for attr_name in dir(self):
+            func = getattr(self, attr_name)
+            if hasattr(func,'_action'):
+                action = ActionItem(*func._action, func = func)
+                self.base_permissions.append(action.name)
+                self.actions[action.name] = (action)
+
+
     def _init_forms(self):
         conv = GeneralModelConverter(self.datamodel)        
         if not self.add_form:
@@ -583,7 +548,8 @@ class BaseCRUDView(BaseModelView):
                     page=pages.get(view.__class__.__name__), page_size=page_sizes.get(view.__class__.__name__)).get('list'))
         return widgets
     
-    def _get_list_widget(self, filters, 
+    def _get_list_widget(self, filters,
+                        actions = None,
                         order_column = '', 
                         order_direction = '',
                         page = None,
@@ -591,6 +557,7 @@ class BaseCRUDView(BaseModelView):
                         widgets = {}, **args):
 
         """ get joined base filter and current active filter for query """
+        actions = actions or self.actions
         page_size = page_size or self.page_size        
         joined_filters = filters.get_joined_filters(self._base_filters)
         count, lst = self.datamodel.query(joined_filters, order_column, order_direction, page=page, page_size=page_size)
@@ -604,29 +571,31 @@ class BaseCRUDView(BaseModelView):
                                                 page_size = page_size,
                                                 count = count,
                                                 pks = pks,
+                                                actions = actions,
                                                 filters = filters,
                                                 generalview_name = self.__class__.__name__
                                                 )
         return widgets
 
 
-    def _get_show_widget(self, id, widgets = {}, show_additional_links = []):
-        if show_additional_links:
-            additional_links = show_additional_links
-        else: additional_links = self.show_additional_links
+    def _get_show_widget(self, id, widgets = None, actions = None):
+        widgets = widgets or {}
+        actions = actions or self.actions
         item = self.datamodel.get(id)
         widgets['show'] = self.show_widget(route_base = self.route_base,
                                                 pk = id,
                                                 label_columns = self.label_columns,
                                                 include_columns = self.show_columns,
                                                 value_columns = self.datamodel.get_values_item(item, self.show_columns),
-                                                additional_links = additional_links,
+                                                actions = actions,
                                                 fieldsets = self.show_fieldsets
                                                 )
         return widgets
 
 
-    def _get_add_widget(self, form = None, exclude_cols = [], widgets = {}):
+    def _get_add_widget(self, form = None, exclude_cols = None, widgets = None):
+        exclude_cols = exclude_cols or []
+        widgets = widgets or {}
         widgets['add'] = self.edit_widget(route_base = self.route_base,
                                                 form = form,
                                                 include_cols = self.add_columns,
@@ -635,7 +604,9 @@ class BaseCRUDView(BaseModelView):
                                                 )
         return widgets
 
-    def _get_edit_widget(self, form = None, exclude_cols = [], widgets = {}):
+    def _get_edit_widget(self, form = None, exclude_cols = None, widgets = None):
+        exclude_cols = exclude_cols or []
+        widgets = widgets or {}
         widgets['edit'] = self.edit_widget(route_base = self.route_base,
                                                 form = form,
                                                 include_cols = self.edit_columns,
@@ -697,7 +668,7 @@ class GeneralView(BaseCRUDView):
     """
         This is the CRUD generic view. If you want to automatically implement create, edit, delete, show, and search form your database tables, inherit your views from this class.
 
-        Notice that this class inherits from BaseCRUDView so all properties from the parent class can be overrided also.
+        Notice that this class inherits from BaseCRUDView so all properties from the parent class can be overriden.
     """
 
     def __init__(self, **kwargs):
@@ -715,13 +686,13 @@ class GeneralView(BaseCRUDView):
 
         form = self.search_form.refresh()
         
-        if self._get_order_args().get(self.__class__.__name__):
-            order_column, order_direction = self._get_order_args().get(self.__class__.__name__)
+        if get_order_args().get(self.__class__.__name__):
+            order_column, order_direction = get_order_args().get(self.__class__.__name__)
         else: order_column, order_direction = '',''
-        page = self._get_page_args().get(self.__class__.__name__)
-        page_size = self._get_page_size_args().get(self.__class__.__name__)
+        page = get_page_args().get(self.__class__.__name__)
+        page_size = get_page_size_args().get(self.__class__.__name__)
         
-        self._get_filter_args()
+        get_filter_args(self._filters)
         
         widgets = self._get_list_widget(filters = self._filters, 
                     order_column = order_column, 
@@ -742,13 +713,13 @@ class GeneralView(BaseCRUDView):
             SHOW
     --------------------------------
     """
-    @expose('/show/<int:pk>', methods=['GET'])
+    @expose('/show/<pk>', methods=['GET'])
     @has_access
     def show(self, pk):
 
-        pages = self._get_page_args()
-        page_sizes = self._get_page_size_args()
-        orders = self._get_order_args()
+        pages = get_page_args()
+        page_sizes = get_page_size_args()
+        orders = get_order_args()
 
         widgets = self._get_show_widget(pk)
         item = self.datamodel.get(pk)
@@ -773,7 +744,7 @@ class GeneralView(BaseCRUDView):
     @has_access
     def add(self):
 
-        self._get_filter_args()
+        get_filter_args(self._filters)
 
         form = self.add_form.refresh()
         exclude_cols = self._filters.get_relation_cols()
@@ -781,7 +752,6 @@ class GeneralView(BaseCRUDView):
         if form.validate_on_submit():
             item = self.datamodel.obj()
             form.populate_obj(item)
-            print "EXT", exclude_cols
             for filter_key in exclude_cols:
                 rel_obj = self.datamodel.get_related_obj(filter_key, self._filters.get_filter_value(filter_key))
                 setattr(item, filter_key, rel_obj)
@@ -802,16 +772,18 @@ class GeneralView(BaseCRUDView):
             EDIT
     ---------------------------
     """
-    @expose('/edit/<int:pk>', methods=['GET', 'POST'])
+    @expose('/edit/<pk>', methods=['GET', 'POST'])
     @has_access
-    def edit(self, pk = 0):
+    def edit(self, pk):
 
-        pages = self._get_page_args()
-        page_sizes = self._get_page_size_args()
-        orders = self._get_order_args()
+        pages = get_page_args()
+        page_sizes = get_page_size_args()
+        orders = get_order_args()
         
         item = self.datamodel.get(pk)
-        self._get_filter_args()
+        # convert pk to correct type, if pk is non string type.
+        pk = self.datamodel.get_pk_value(item)
+        get_filter_args(self._filters)
         exclude_cols = self._filters.get_relation_cols()
 
         if request.method == 'POST':
@@ -821,7 +793,7 @@ class GeneralView(BaseCRUDView):
             form._id = pk
             if form.validate():
                 form.populate_obj(item)
-
+                # fill the form with the suppressed cols, generated from exclude_cols
                 for filter_key in exclude_cols:
                     rel_obj = self.datamodel.get_related_obj(filter_key, self._filters.get_filter_value(filter_key))
                     setattr(item, filter_key, rel_obj)
@@ -857,7 +829,7 @@ class GeneralView(BaseCRUDView):
             DELETE
     ---------------------------
     """
-    @expose('/delete/<int:pk>')
+    @expose('/delete/<pk>')
     @has_access
     def delete(self, pk):
         item = self.datamodel.get(pk)
@@ -874,18 +846,15 @@ class GeneralView(BaseCRUDView):
         return send_file(self.baseapp.app.config['UPLOAD_FOLDER'] + filename, 
                     attachment_filename = uuid_originalname(filename), 
                     as_attachment = True)
+
+
+    @expose('/action/<string:name>/<pk>')
+    @has_access
+    def action(self, name, pk):
+        if self.baseapp.sm.has_access(name, self.__class__.__name__):
+            action = self.actions.get(name)
+            return action.func(self.datamodel.get(pk))
+        else:
+            flash("Access is Denied %s %s" % (name, self.__class__.__name__),"danger")
+            return redirect('.')
         
-
-
-
-class AdditionalLinkItem():
-    name = ""
-    label = ""
-    href = ""
-    icon = ""
-
-    def __init__(self, name, label, href, icon=""):
-        self.name = name
-        self.label = label
-        self.href = href
-        self.icon = icon
